clear
cd('/Users/PriceTransparency/code')


%%%%%%%%%%%%%%%%%%%%%%%%
%     SIMULATE DATA
%%%%%%%%%%%%%%%%%%%%%%%%

Nvisit = 5000; % number of choice situations
Nprov = 3; % number of choices within each visit
Nchoice = Nvisit*Nprov; % total number of choices

visitid = sort(repmat((1:Nvisit)',Nprov,1));

% Set paramters
param.price_mu = -0.8; % Coefficients on price
param.snoise_sigma = 25; % Variance of price signal
param.dchars = [-0.1; 0.5]; % Coefficient on distance, etc
param.provid = [0; 2; 6]; % Alt-specific FEs (first option is normalized to 0)

% Provider FE
provid = repmat((1:Nprov)',Nvisit,1);
prov_fe = repmat(param.provid,Nvisit,1);

% Simulate price
price = TruncatedGaussian(-10, [-10,Inf],[Nvisit*Nprov, 1]) +10;

% Simulate other characteristics (e.g. distance)
x1 = random('norm', 5, 10,[Nvisit*Nprov,1]);
x2 = random('norm', 15, 10,[Nvisit*Nprov,1]);

% Simulate whether individual knows price (h=1 if individual knows prices)
h = repelem(binornd(1,0.5,Nvisit,1),Nprov);

% Simulate price noise
snoise = random('normal', 0, param.snoise_sigma,[Nchoice,1]);

mean_price = accumarray(visitid,price,[],@mean);
mean_price = mean_price(visitid);
std_price = accumarray(visitid,price,[],@std);
std_price = std_price(visitid);

% Posterior (note outside option)
rho_jkt = std_price.^-2;
rho_s = param.snoise_sigma^-2;
std_posterior = (rho_jkt(visitid) + rho_s).^-1;

weight = (std_price .* std_price) ./ (param.snoise_sigma * param.snoise_sigma + std_price .* std_price);
mean_posterior = weight .* (price + param.snoise_sigma * snoise/std(snoise)) + (1 - weight) .* mean_price;

% Simulate utility
v_s = prov_fe + param.price_mu.*price + [x1, x2]*param.dchars;
v_ns = prov_fe + param.price_mu.*(mean_posterior) + [x1, x2]*param.dchars;
u_s = v_s + random('ev', 0, 1,[Nchoice,1]);
u_ns = v_ns + random('ev', 0, 1,[Nchoice,1]);

util = u_s.*h + u_ns.*(1-h);

% Find max utility (including outside option with 0 utility)
max_u = accumarray(visitid,util,[],@max);
max_u = max_u(visitid);
choice = (max_u==util);

disp('Tabulate choices:')
disp(crosstab(choice, provid))

disp('Tabulate probability of choosing option with lowest price by search:')
min_price = accumarray(visitid,price,[],@min);
is_min = price==min_price(visitid);
xtab  = crosstab(is_min(choice==1)==1, h(choice==1));
disp(xtab)
disp(xtab(:,2)./sum(xtab,2))

max_price = accumarray(visitid,price,[],@max);
is_max = price==max_price(visitid);
xtab  = crosstab(is_max(choice==1)==1, h(choice==1));
disp(xtab)
disp(xtab(:,2)./sum(xtab,2))

% Save
data = table(visitid,choice,provid,h,price,x1,x2,mean_price,std_price);
save('data.mat','data')

